@@ -7,8 +7,9 @@ from django import forms
 from django.db import models
 from django.core.exceptions import ValidationError
 from django.utils.text import capfirst
-
-
+from django.contrib.humanize.templatetags.humanize \
+        import apnumber
+from django.template.defaultfilters import pluralize
 
 # This is a copy of http://djangosnippets.org/snippets/513/
 #
@@ -43,7 +44,7 @@ class PickledObjectField(models.Field):
                 # If an error was raised, just return the plain value
                 return value
 
-    def get_db_prep_save(self, value):
+    def get_db_prep_save(self, value, connection):
         if value is not None and not isinstance(value, PickledObject):
             value = PickledObject(pickle.dumps(value))
         return value
@@ -54,13 +55,18 @@ class PickledObjectField(models.Field):
     def value_to_string(self, obj):
 	return PickledObject(pickle.dumps(obj))
 
-    def get_db_prep_lookup(self, lookup_type, value):
+    def get_db_prep_lookup(self, lookup_type, value, connection,
+            prepared=False):
         if lookup_type == 'exact':
-            value = self.get_db_prep_save(value)
-            return super(PickledObjectField, self).get_db_prep_lookup(lookup_type, value)
+            value = self.get_db_prep_save(value, connection)
+            return super(PickledObjectField, self) \
+                    .get_db_prep_lookup(lookup_type, value, connection,
+                            prepared=prepared)
         elif lookup_type == 'in':
-            value = [self.get_db_prep_save(v) for v in value]
-            return super(PickledObjectField, self).get_db_prep_lookup(lookup_type, value)
+            value = [self.get_db_prep_save(v, connection) for v in value]
+            return super(PickledObjectField, self) \
+                    .get_db_prep_lookup(lookup_type, value, connection,
+                            prepared=prepared)
         else:
             raise TypeError('Lookup type %s is not supported.' % lookup_type)
 
@@ -110,8 +116,7 @@ class MultiSelectField(models.Field):
         return self.get_choices(include_blank=False)
 
     def _get_FIELD_display(self, field):
-        value = getattr(self, field.attname)
-        choicedict = dict(field.choices)
+        pass
 
     def formfield(self, **kwargs):
         # don't call super, as that overrides default widget if it has choices
@@ -122,7 +127,7 @@ class MultiSelectField(models.Field):
         defaults.update(kwargs)
         return MultiSelectFormField(**defaults)
 
-    def get_db_prep_value(self, value):
+    def get_db_prep_value(self, value, connection, prepared=False):
         if isinstance(value, basestring):
             return value
         elif isinstance(value, list):
