@@ -5,8 +5,8 @@ import os
 gettext_noop = lambda s: s
 
 DEBUG = True
-USE_DEBUG_TOOLBAR = False
-STATIC_SERVE = True
+USE_DEBUG_TOOLBAR = DEBUG
+STATIC_SERVE = DEBUG
 TEMPLATE_DEBUG = DEBUG
 _PROJECT_PATH = os.path.join(os.path.dirname(__file__), '..')
 
@@ -62,12 +62,14 @@ MEDIA_ROOT = os.path.join(_PROJECT_PATH, 'media')
 # URL that handles the media served from MEDIA_ROOT. Make sure to use a
 # trailing slash if there is a path component (optional in other cases).
 # Examples: "http://media.lawrence.com", "http://example.com/media/"
-MEDIA_URL = '/media/'
+
+STATIC_ROOT = os.path.join(_PROJECT_PATH, 'static')
+STATIC_URL = '/static/'
 
 # URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
 # trailing slash.
 # Examples: "http://foo.com/media/", "/media/".
-ADMIN_MEDIA_PREFIX = '/media/admin/'
+ADMIN_MEDIA_PREFIX = '/static/admin/'
 
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '0!=(1kc6kri-ui+tmj@mr+*0bvj!(p*r0duu2n=)7@!p=pvf9n'
@@ -86,10 +88,12 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     'django.core.context_processors.media',
     'django.core.context_processors.request',
     'django.contrib.messages.context_processors.messages',
+    'django.core.context_processors.static',
 )
 
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
+    'django.middleware.http.ConditionalGetMiddleware',
     'django.contrib.csrf.middleware.CsrfMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.locale.LocaleMiddleware',
@@ -107,12 +111,14 @@ TEMPLATE_DIRS = (
 )
 
 INSTALLED_APPS = (
+    'django.contrib.staticfiles',
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'django.contrib.sessions',
     'django.contrib.messages',
     'django.contrib.admin',
     'django.contrib.sites',
+    'authentic2.nonce',
     'authentic2.saml',
     'authentic2.idp',
     'authentic2.idp.saml',
@@ -122,6 +128,7 @@ INSTALLED_APPS = (
     'authentic2.auth2_auth.auth2_oath',
     'authentic2.auth2_auth.auth2_ssl',
     'south',
+    'authentic2.attribute_aggregator',
 )
 
 MESSAGE_STORAGE = 'django.contrib.messages.storage.session.SessionStorage'
@@ -179,7 +186,8 @@ IDP_BACKENDS = [ ]
 IDP_SAML2 = True
 
 # You MUST changes these keys, they are just for testing !
-SAML_SIGNING_KEY = '''-----BEGIN CERTIFICATE-----
+LOCAL_METADATA_CACHE_TIMEOUT = 600
+SAML_SIGNATURE_PUBLIC_KEY = '''-----BEGIN CERTIFICATE-----
 MIIDIzCCAgugAwIBAgIJANUBoick1pDpMA0GCSqGSIb3DQEBBQUAMBUxEzARBgNV
 BAoTCkVudHJvdXZlcnQwHhcNMTAxMjE0MTUzMzAyWhcNMTEwMTEzMTUzMzAyWjAV
 MRMwEQYDVQQKEwpFbnRyb3V2ZXJ0MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIB
@@ -199,7 +207,7 @@ JumlBc6IViKhJeo1wiBBrVRIIkKKevHKQzteK8pWm9CYWculxT26TZ4VWzGbo06j
 o2zbumirrLLqnt1gmBDvDvlOwC/zAAyL4chbz66eQHTiIYZZvYgy
 -----END CERTIFICATE-----'''
 
-SAML_PRIVATE_KEY = '''-----BEGIN RSA PRIVATE KEY-----
+SAML_SIGNATURE_PRIVATE_KEY = '''-----BEGIN RSA PRIVATE KEY-----
 MIIEpAIBAAKCAQEAvxFkfPdndlGgQPDZgFGXbrNAc/79PULZBuNdWFHDD9P5hNhZ
 n9Kqm4Cp06Pe/A6u+g5wLnYvbZQcFCgfQAEzziJtb3J55OOlB7iMEI/T2AX2WzrU
 H8QT8NGhABONKU2Gg4XiyeXNhH5R7zdHlUwcWq3ZwNbtbY0TVc+n665EbrfV/59x
@@ -241,20 +249,67 @@ IDP_CAS = False
 # expiration time in seconds of the cas tickets
 # CAS_TICKET_EXPIRATION = 240
 
-import logging
 # Logging settings
-LOG_FILENAME = os.path.join(_PROJECT_PATH, 'log.log')
-LOG_FILE_LEVEL = logging.DEBUG
-LOG_SYSLOG = True
-LOG_SYS_LEVEL = logging.WARNING
-
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': True,
+    'formatters': {
+        'verbose': {
+            'format': '[%(asctime)s] %(levelname)-8s %(name)s.%(message)s',
+            'datefmt': '%Y-%m-%d %a %H:%M:%S'
+        },
+    },
+    'handlers': {
+        'null': {
+            'level':'DEBUG',
+            'class':'django.utils.log.NullHandler',
+        },
+        'console': {
+            'level':'DEBUG',
+            'class':'logging.StreamHandler',
+            'formatter': 'verbose'
+        },
+        'local_file': {
+            'level':'DEBUG',
+            'class':'logging.FileHandler',
+            'formatter': 'verbose',
+            'filename': os.path.join(_PROJECT_PATH, 'log.log'),
+        },
+        'syslog': {
+            'level':'INFO',
+            'class':'logging.handlers.SysLogHandler',
+        },
+        'mail_admins': {
+            'level': 'ERROR',
+            'class': 'django.utils.log.AdminEmailHandler',
+            'include_html': True,
+        }
+    },
+    'loggers': {
+        'django': {
+            'handlers':['null'],
+            'propagate': True,
+            'level':'INFO',
+        },
+        'django.request': {
+            'handlers': ['mail_admins'],
+            'level': 'ERROR',
+            'propagate': False,
+        },
+    },
+    'root': {
+            'handlers': ['console', 'local_file'],
+            'level': 'DEBUG',
+    }
+}
 
 # local_settings.py can be used to override environment-specific settings
 # like database and email that differ between development and production.
 try:
     from local_settings import *
-except ImportError:
-    pass
+except ImportError, e:
+    if 'local_settings' in e.args[0]:
+        pass
 
 if USE_DEBUG_TOOLBAR:
     MIDDLEWARE_CLASSES += ('debug_toolbar.middleware.DebugToolbarMiddleware',)
@@ -267,6 +322,7 @@ if AUTH_SAML2:
             'authentic2.authsaml2.backends.AuthSAML2TransientBackend')
     AUTH_FRONTENDS += ('authentic2.authsaml2.frontend.AuthSAML2Frontend',)
     IDP_BACKENDS += ('authentic2.authsaml2.backends.AuthSAML2Backend',)
+    DISPLAY_MESSAGE_ERROR_PAGE = True
 
 if AUTH_OPENID:
     INSTALLED_APPS += ('django_authopenid',)
@@ -288,37 +344,3 @@ if IDP_OPENID:
 
 if IDP_CAS:
     INSTALLED_APPS += ('authentic2.idp.idp_cas',)
-
-from logging.handlers import SysLogHandler
-import threading
-import sys
-
-_LOCAL = threading.local()
-
-def getlogger():
-
-    logger = getattr(_LOCAL, 'logger', None)
-    if logger is not None:
-        return logger
-    logger = logging.getLogger()
-    logger.setLevel(logging.DEBUG)
-
-    formatter = logging.Formatter('[%(asctime)s] %(levelname)-8s %(name)s.%(message)s','%Y-%m-%d %a %H:%M:%S')
-
-    if LOG_FILENAME:
-        log_handler = logging.FileHandler(LOG_FILENAME)
-        log_handler.setFormatter(formatter)
-        log_handler.setLevel(LOG_FILE_LEVEL)
-        logger.addHandler(log_handler)
-
-    if LOG_SYSLOG:
-        syslog_handler = SysLogHandler(address = '/dev/log')
-        formatter = logging.Formatter('authentic %(levelname)-8s %(name)s.%(message)s','%Y-%m-%d %a %H:%M:%S')
-        syslog_handler.setFormatter(formatter)
-        syslog_handler.setLevel(LOG_SYS_LEVEL)
-        logger.addHandler(syslog_handler)
-
-    setattr(_LOCAL,'logger',logger)
-    return logger
-
-getlogger()
