@@ -1,6 +1,5 @@
 from django.conf.urls.defaults import *
 from django.core.urlresolvers import reverse
-from django.contrib import admin
 from django.contrib.auth.decorators import login_required
 import profiles.views
 
@@ -8,6 +7,8 @@ import authentic2.idp.views
 import settings
 from forms import AuthenticRegistrationForm
 
+from .admin import admin
+
 admin.autodiscover()
 handler500 = 'authentic2.views.server_error'
 
@@ -15,12 +16,15 @@ handler500 = 'authentic2.views.server_error'
 urlpatterns = patterns('',
     (r'^', include('authentic2.auth2_auth.urls')),
     (r'^redirect/(.*)', 'authentic2.views.redirect'),
+    url(r'^accounts/register/registration_success', 'authentic2.views.registration_success', name='registration_success'),
     url(r'^accounts/register',
        'registration.views.register',
-       { 'form_class': AuthenticRegistrationForm },
+       {'backend':'registration.backends.default.DefaultBackend',
+        'success_url' : 'registration_success',
+        'form_class': AuthenticRegistrationForm },
        name='registration_register',
        ),
-    (r'^accounts/', include('registration.urls')),
+    (r'^accounts/', include('registration.backends.default.urls')),
     url(r'^logout$', 'authentic2.idp.views.logout', name='auth_logout'),
     (r'^admin/admin_log_view/log/', 'authentic2.admin_log_view.views.admin_view'),
     (r'^admin/', include(admin.site.urls)),
@@ -41,11 +45,9 @@ urlpatterns += patterns('',
 )
 
 if settings.STATIC_SERVE:
-    urlpatterns += patterns('',
-        url(
-            regex = r'^media/(?P<path>.*)$',
-            view = 'django.views.static.serve',
-            kwargs = {'document_root': settings.MEDIA_ROOT}),
+    print 'static server'
+    urlpatterns += patterns('django.contrib.staticfiles.views',
+        url(r'^static/(?P<path>.*)$', 'serve'),
     )
 
 if getattr(settings, 'IDP_OPENID', False):
